Announcements
=============

.. versionchanged:: 4.0

   In prior releases this feature was called whiteboard messages.

Provide info to your translators by posting announcements, site-wide, per project, component, or language.

Announce the purpose, deadlines, status, or specify targets for translation.

The users will receive notification on the announcements for watched
projects (unless they opt out).

This can be useful for various things from announcing the purpose of the website to
specifying targets for translations.

The announcements can posted on each level in the :guilabel:`Manage` menu, using
:guilabel:`Post announcement`:

.. image:: /screenshots/announcement-project.png
    :alt: Image showing a message that reads: "Translations will be used only if they reach 60%" atop the dashboard view.

It can be also added using the admin interface:

.. image:: /screenshots/announcement.png

The announcements are then shown based on their specified context:

No context specified

    Shown on dashboard (landing page).

Project specified

    Shown within the project, including all its components and translations.

Component specified

    Shown for a given component and all its translations.

Language specified

    Shown on the language overview and all translations in that language.


This is how it looks on the language overview page:

.. image:: /screenshots/announcement-language.png
   :alt: Image showing a message that reads: "Czech translators rock!" atop the Czech language overview.
